@@ -32,6 +32,7 @@
 #  include <stdio.h>
 # endif // DEBUG
 # include <set>
+# include <stack>
 
 /** Abstract base class for LTL formulae */
 class Ltl
@@ -120,12 +121,10 @@ public:
   bool operator< (const class Ltl& other) const;
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  virtual void expand (unsigned state,
-		       class LtlGraphNode& node,
-		       class LtlGraph& graph) const = 0;
+  /// @param to_expand	stack of nodes to be expanded
+  virtual void expand (class LtlGraphNode& node,
+		       std::stack<class LtlGraphNode*>& to_expand) const = 0;
 
 # ifdef DEBUG
   /// Stream output
@@ -181,12 +180,10 @@ public:
   unsigned getValue () const { return m_value; }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -238,12 +235,10 @@ public:
   operator bool () const { return m_true; }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -318,12 +313,10 @@ public:
   }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -407,12 +400,10 @@ public:
   }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -491,12 +482,10 @@ public:
   const class Ltl& getFormula () const { return m_formula; }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
@@ -580,12 +569,10 @@ public:
   const class Ltl& getRight () const { return m_right; }
 
   /// Implements operator/operand specific details of the expansion algorithm.
-  /// @param state	state number in the generalized Bchi automaton
   /// @param node	the node representing the formula
-  /// @param graph	graph representation of the generalized Bchi automaton
-  void expand (unsigned state,
-	       class LtlGraphNode& node,
-	       class LtlGraph& graph) const;
+  /// @param to_expand	stack of nodes to be expanded
+  void expand (class LtlGraphNode& node,
+	       std::stack<class LtlGraphNode*>& to_expand) const;
 
 # ifdef DEBUG
   /// Stream output
