@@ -9,7 +9,7 @@
 # include <string.h>
 # include <assert.h>
 # include <map>
-# include "s_list.h"
+# include <list>
 
 # include "util.h"
 # include "Error.h"
@@ -18,7 +18,7 @@
  * Transition in an algebraic system net
  */
 
-/* Copyright  1998-2003 Marko Mkel (msmakela@tcs.hut.fi).
+/* Copyright  1998-2003,2005 Marko Mkel (msmakela@tcs.hut.fi).
 
    This file is part of MARIA, a reachability analyzer and model checker
    for high-level Petri nets.
@@ -55,7 +55,7 @@ public:
     uRemove	//< Remove gates depending on un-unifiable variables
   };
   /** List of gate expressions */
-  typedef slist<class Expression*> GateList;
+  typedef std::list<class Expression*> GateList;
   /** Map from names to variables defined in the transition */
   typedef std::map<const char*,class VariableDefinition*,
     struct ltstr> VariableMap;
@@ -431,7 +431,7 @@ private:
    * @param numOptVars	number of optional variables
    */
   void compileAnalysis (class CExpression& cexpr,
-			const slist<const class Place*>& inputPlaces,
+			const std::list<const class Place*>& inputPlaces,
 			unsigned numOptVars) const;
 public:
   /** Compile the expressions of the transition
